# ipyaggrid

[![Latest Version](https://img.shields.io/pypi/v/ipyaggrid.svg)](https://pypi.python.org/pypi/ipyaggrid/)
[![Downloads](https://img.shields.io/pypi/dm/ipyaggrid.svg)](https://pypi.python.org/pypi/ipyaggrid/)
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gl/DGothrek%2Fipyaggrid/binder-demo)

### Doc

See documentation: [widgetti.github.io/ipyaggrid/](https://widgetti.github.io/ipyaggrid/).

Demo notebooks are in [docs/notebooks](/docs/notebooks) and available on mybinder (see link above).

### Credits

ipyaggrid was created by [Louis Raison](https://gitlab.com/DGothrek) and [oscar6echo](https://gitlab.com/oscar6echo) and originally maintained at https://gitlab.com/DGothrek/ipyaggrid .

For more context, read the original article [Harnessing the power of ag-Grid in Jupyter](https://medium.com/@olivier.borderies/harnessing-the-power-of-ag-grid-in-jupyter-3ae27fb21012).

[Mario Buikhuizen](https://github.com/mariobuikhuizen) and [Maarten Breddels](https://github.com/maartenbreddels) took over maintenance in 2022.

### Sponsors

Project ipyaggrid receives direct funding from the following sources:

[![MSD](docs/content/.vuepress/public/msd-logo.svg)](https://msd.com)
